@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2008 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -39,6 +39,7 @@ struct jhtml_t {
     int                 h4_align_flag;
     int                 h5_align_flag;
     int                 h6_align_flag;
+    int                 font_flag;
 
     device_table        *spec;
     mod_chxj_config     *conf;
@@ -49,7 +50,7 @@ struct jhtml_t {
 /*----------------------------------------------------------------------------*/
 /* Prototype                                                                  */
 /*----------------------------------------------------------------------------*/
-extern char *chxj_exchange_jhtml(
+extern char *chxj_convert_jhtml(
   request_rec               *r,
   device_table              *spec,
   const char                *src,
@@ -58,4 +59,7 @@ extern char *chxj_exchange_jhtml(
   chxjconvrule_entry        *entryp,
   cookie_t                  *cookie);
 
+
+extern char *chxj_jhtml_emoji_only_converter(request_rec *r, device_table *spec, const char *src, apr_size_t len);
+
 #endif
