@@ -282,6 +282,7 @@ typedef enum {
 } tag_type;
 
 typedef struct mod_chxj_config mod_chxj_config;
+typedef struct mod_chxj_req_config_t mod_chxj_req_config;
 
 #if defined(USE_MYSQL_COOKIE)
 #  include "chxj_mysql.h"
@@ -362,6 +363,13 @@ struct mod_chxj_config {
   char                  *post_log;              /* post log environment name. */
 };
 
+struct mod_chxj_req_config_t {
+  char               *user_agent;
+  device_table       *spec;
+  ap_filter_t        *f;
+  chxjconvrule_entry *entryp;
+};
+
 #define IS_COOKIE_STORE_DBM(X)      ((X) == COOKIE_STORE_TYPE_DBM)
 #define IS_COOKIE_STORE_MYSQL(X)    ((X) == COOKIE_STORE_TYPE_MYSQL)
 #define IS_COOKIE_STORE_MEMCACHE(X) ((X) == COOKIE_STORE_TYPE_MEMCACHE)
@@ -386,6 +394,8 @@ struct mod_chxj_config {
 #define CONVRULE_NOCACHE_ON_BIT       (0x00000800)
 #define CONVRULE_EMOJI_ONLY_BIT       (0x00001000)
 #define CONVRULE_ENVINFO_ONLY_BIT     (0x00002000)
+#define CONVRULE_COOKIE_ONLY_BIT      (0x00004000)
+#define CONVRULE_OVERWRITE_X_CLIENT_TYPE_BIT (0x00008000)
 
 #define CONVRULE_ENGINE_ON_CMD        "EngineOn"
 #define CONVRULE_ENGINE_OFF_CMD       "EngineOff"
@@ -404,6 +414,8 @@ struct mod_chxj_config {
 #define CONVRULE_NOCACHE_ON_CMD       "NoCacheOn"
 #define CONVRULE_EMOJI_ONLY_CMD       "EmojiOnly"
 #define CONVRULE_ENVINFO_ONLY_CMD     "EnvInfoOnly"
+#define CONVRULE_COOKIE_ONLY_CMD      "CookieOnly"
+#define CONVRULE_OVERWRITE_X_CLIENT_TYPE_CMD "OverwriteXClientType"
 
 
 #define CONVRULE_FLAG_NOTMATCH        (0x00000001)
@@ -437,6 +449,7 @@ typedef struct {
 #define HTTP_HOST             "Host"
 #define CHXJ_HTTP_USER_AGENT  "CHXJ_HTTP_USER_AGENT"
 #define CHXJ_HEADER_ORIG_CLIENT_IP "X-Chxj-Orig-Client-Ip"
+#define CHXJ_HEADER_ORIG_CLIENT_TYPE "X-Chxj-Orig-Client-Type"
 
 module AP_MODULE_DECLARE_DATA chxj_module;
 
@@ -479,6 +492,9 @@ extern char *chxj_node_convert_chxjif_only(
   apr_size_t   *len
 );
 
+extern void chxj_remove_filter(request_rec *r);
+extern mod_chxj_req_config *chxj_get_req_config(request_rec *r);
+
 #define IMAGE_CACHE_LIMIT_FMT_LEN  (20)
 
 
@@ -488,6 +504,23 @@ extern void *rpl_malloc(size_t n);
 
 
 #define TO_ADDR(X) ((unsigned int)(apr_size_t)(X))
+#if APR_MAJOR_VERSION < 1
+  #ifndef APR_FOPEN_READ
+    #define APR_FOPEN_READ APR_READ
+  #endif
+  #ifndef APR_FOPEN_BUFFERED
+    #define APR_FOPEN_BUFFERED APR_BUFFERED
+  #endif
+  #ifndef APR_FOPEN_BINARY
+    #define APR_FOPEN_BINARY APR_BINARY
+  #endif
+  #ifndef APR_FOPEN_CREATE
+    #define APR_FOPEN_CREATE APR_CREATE
+  #endif
+  #ifndef APR_FOPEN_WRITE
+    #define APR_FOPEN_WRITE APR_WRITE
+  #endif
+#endif
 #endif
 /*
  * vim:ts=2 et
