@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -426,7 +426,7 @@ chxj_convert_chtml50(
   chtml50_t chtml50;
   Doc       doc;
 
-  DBG(r, "start chxj_convert_chtml50()");
+  DBG(r, "REQ[%X] start %s()",TO_ADDR(r),__func__);
 
   /*--------------------------------------------------------------------------*/
   /* If qrcode xml                                                            */
@@ -434,11 +434,11 @@ chxj_convert_chtml50(
   *dstlen = srclen;
   dst = chxj_qr_code_blob_handler(r, src, (size_t*)dstlen);
   if (dst) {
-    DBG(r,"i found qrcode xml");
-    DBG(r, "end chxj_convert_chtml50()");
+    DBG(r,"REQ[%X] found qrcode xml", TO_ADDR(r));
+    DBG(r, "REQ[%X] end %s()",TO_ADDR(r),__func__);
     return dst;
   }
-  DBG(r,"not found qrcode xml");
+  DBG(r,"REQ[%X] not found qrcode xml", TO_ADDR(r));
 
   /*--------------------------------------------------------------------------*/
   /* The CHTML structure is initialized.                                      */
@@ -490,7 +490,7 @@ chxj_convert_chtml50(
   chxj_dump_out("[src] CHTML -> CHTML4.0", dst, *dstlen);
 #endif
 
-  DBG(r, "end chxj_convert_chtml50()");
+  DBG(r, "REQ[%X] end %s()", TO_ADDR(r),__func__);
   return dst;
 }
 
@@ -545,14 +545,14 @@ s_chtml50_search_emoji(chtml50_t *chtml50, char *txt, char **rslt)
   r   = chtml50->doc->r;
 
   if (!spec) {
-    DBG(r,"spec is NULL");
+    DBG(r,"REQ[%X] spec is NULL", TO_ADDR(r));
   }
 
   for (ee = chtml50->conf->emoji;
        ee;
        ee = ee->next) {
     if (ee->imode == NULL) {
-      DBG(r, "emoji->imode is NULL");
+      DBG(r, "REQ[%X] emoji->imode is NULL", TO_ADDR(r));
       continue;
     }
 
@@ -591,7 +591,7 @@ chxj_chtml50_emoji_only_converter(request_rec *r, device_table *spec, const char
   chtml50 = &__chtml50;
   doc     = &__doc;
 
-  DBG(r, "REQ[%X] start chxj_chtml50_emoji_eonly_converter()", (unsigned int)(apr_size_t)r);
+  DBG(r, "REQ[%X] start %s()", TO_ADDR(r),__func__);
   memset(doc,     0, sizeof(Doc));
   memset(chtml50, 0, sizeof(chtml50_t));
 
@@ -632,7 +632,7 @@ chxj_chtml50_emoji_only_converter(request_rec *r, device_table *spec, const char
   }
   chtml50->out = chxj_buffered_write_flush(chtml50->out, &doc->buf);
 
-  DBG(r, "REQ[%X] end chxj_chtml50_emoji_eonly_converter()", (unsigned int)(apr_size_t)r);
+  DBG(r, "REQ[%X] end %s()", TO_ADDR(r),__func__);
   return chtml50->out;
 }
 
