@@ -1512,7 +1512,7 @@ s_fixup_color(MagickWand *magick_wand, request_rec *r, device_table *spec, img_c
     if (MagickQuantizeImage(magick_wand,
                            spec->color,
                            RGBColorspace,
-                           0,
+                           4, /* tree depth of 4 */
                            1,
                            0) == MagickFalse) {
       EXIT_MAGICK_ERROR();
@@ -1529,7 +1529,7 @@ s_fixup_color(MagickWand *magick_wand, request_rec *r, device_table *spec, img_c
     if (MagickQuantizeImage(magick_wand,
                            spec->color,
                            GRAYColorspace,
-                           0,
+                           4, /* tree depth of 4 */
                            1,
                            0) == MagickFalse) {
       EXIT_MAGICK_ERROR();
