@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -427,14 +427,15 @@ chxj_convert_xhtml_mobile_1_0(
   xhtml_t   xhtml;
   Doc       doc;
 
-  DBG(r,"start chxj_convert_xhtml_mobile_1_0()");
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
   /*--------------------------------------------------------------------------*/
   /* If qrcode xml                                                            */
   /*--------------------------------------------------------------------------*/
   *dstlen = srclen;
   dst = chxj_qr_code_blob_handler(r, src, (size_t*)dstlen);
   if (dst != NULL) {
-    DBG(r,"end chxj_convert_xhtml_mobile_1_0() (found qrcode.xml)");
+    DBG(r,"REQ[%X] found qrcode.xml", TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return dst;
   }
 
@@ -487,7 +488,7 @@ chxj_convert_xhtml_mobile_1_0(
   chxj_dump_out("[dst] CHTML->XHTML", dst, *dstlen);
 #endif
 
-  DBG(r,"end chxj_convert_xhtml_mobile_1_0()");
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
   return dst;
 }
 
@@ -542,7 +543,7 @@ s_xhtml_search_emoji(xhtml_t *xhtml, char *txt, char **rslt)
   r = xhtml->doc->r;
 
   if (spec == NULL) {
-    DBG(r,"spec is NULL");
+    DBG(r,"REQ[%X] spec is NULL", TO_ADDR(r));
   }
 
   for (ee = xhtml->conf->emoji;
@@ -551,7 +552,7 @@ s_xhtml_search_emoji(xhtml_t *xhtml, char *txt, char **rslt)
     unsigned char hex1byte;
     unsigned char hex2byte;
     if (!ee->imode) {
-      DBG(r,"emoji->imode is NULL");
+      DBG(r,"REQ[%X] emoji->imode is NULL", TO_ADDR(r));
       continue;
     }
 
@@ -667,7 +668,7 @@ chxj_xhtml_emoji_only_converter(request_rec *r, device_table *spec, const char *
   xhtml = &__xhtml;
   doc   = &__doc;
 
-  DBG(r, "REQ[%X] start chxj_xhtml_emoji_eonly_converter()", (unsigned int)(apr_size_t)r);
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
   memset(doc,     0, sizeof(Doc));
   memset(xhtml, 0, sizeof(xhtml_t));
 
@@ -708,7 +709,7 @@ chxj_xhtml_emoji_only_converter(request_rec *r, device_table *spec, const char *
   }
   xhtml->out = chxj_buffered_write_flush(xhtml->out, &doc->buf);
 
-  DBG(r, "REQ[%X] end chxj_xhtml_emoji_eonly_converter()", (unsigned int)(apr_size_t)r);
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
   return xhtml->out;
 }
 
@@ -2926,7 +2927,7 @@ s_xhtml_1_0_text_tag(void *pdoc, Node *child)
     char *out;
     int rtn = s_xhtml_search_emoji(xhtml, &textval[ii], &out);
     if (rtn != 0) {
-      DBG(r,"[%s][%d]", out, rtn);
+      DBG(r,"REQ[%X] [%s][%d]", TO_ADDR(r), out, rtn);
       tdst = qs_out_apr_pstrcat(r, tdst, out, &tdst_len);
       ii+=(rtn - 1);
       continue;
