@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2008 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,12 +21,14 @@
  * ignore space
  */
 int
-qs_ignore_sp(Doc* UNUSED(doc), const char* s, int len) 
+qs_ignore_sp(Doc *UNUSED(doc), const char *s, int len) 
 {
   int ii;
-  char* sp;
+  char *sp;
 
-  sp = (char*)s;
+  if (! s) return 0;
+  if (len <= 0) return 0;
+  sp = (char *)s;
 
   for(ii=0;
       *sp && is_white_space(*sp) && ii<len;
@@ -38,10 +40,13 @@ qs_ignore_sp(Doc* UNUSED(doc), const char* s, int len)
 
 
 int
-qs_ignore_sp_and_quote(Doc* UNUSED(doc), const char* s, int len) 
+qs_ignore_sp_and_quote(Doc *UNUSED(doc), const char *s, int len) 
 {
   int   ii;
-  char* sp = (char*)s;
+  char  *sp = (char *)s;
+
+  if (! s) return 0;
+  if (len <= 0) return 0;
 
   for(ii=0;
       *sp && (is_white_space(*sp) || is_quote(*sp)) && ii<len;
